@@ -15,6 +15,9 @@ from typing import (
     cast,
 )
 
+from cwl_utils.errors import SubstitutionError
+from cwl_utils.expression import scanner as scan_expression
+from cwl_utils.sandboxjs import code_fragment_to_js, exec_js_process
 from pkg_resources import resource_stream
 from ruamel.yaml.comments import CommentedMap, CommentedSeq
 from schema_salad.avro.schema import (
@@ -29,10 +32,7 @@ from schema_salad.utils import json_dumps
 from schema_salad.validate import validate_ex
 
 from .errors import WorkflowException
-from .expression import SubstitutionError
-from .expression import scanner as scan_expression
 from .loghandler import _logger
-from .sandboxjs import code_fragment_to_js, exec_js_process
 
 
 def is_expression(tool, schema):
