@@ -10,6 +10,7 @@ from .util import (
     get_main_output,
     needs_singularity,
     needs_singularity_2_6,
+    needs_singularity_3_or_newer,
     working_directory,
 )
 
@@ -107,7 +108,7 @@ def test_singularity_local(tmp_path: Path) -> None:
 
 
 @needs_singularity_2_6
-def test_singularity_docker_image_id_in_tool(tmp_path: Path) -> None:
+def test_singularity2_docker_image_id_in_tool(tmp_path: Path) -> None:
     workdir = tmp_path / "working_dir"
     workdir.mkdir()
     with working_directory(workdir):
@@ -128,3 +129,28 @@ def test_singularity_docker_image_id_in_tool(tmp_path: Path) -> None:
             ]
         )
         assert result_code1 == 0
+
+
+@needs_singularity_3_or_newer
+def test_singularity3_docker_image_id_in_tool(tmp_path: Path) -> None:
+    workdir = tmp_path / "working_dir"
+    workdir.mkdir()
+    with working_directory(workdir):
+        result_code, stdout, stderr = get_main_output(
+            [
+                "--singularity",
+                get_data("tests/sing_pullfolder_test.cwl"),
+                "--message",
+                "hello",
+            ]
+        )
+        assert result_code == 0
+        result_code1, stdout, stderr = get_main_output(
+            [
+                "--singularity",
+                get_data("tests/debian_image_id2.cwl"),
+                "--message",
+                "hello",
+            ]
+        )
+        assert result_code1 == 0
