@@ -50,16 +50,16 @@ def test_udocker_usage_should_not_write_cid_file(udocker: str, tmp_path: Path) -
     """Confirm that no cidfile is made when udocker is used."""
 
     with working_directory(tmp_path):
-        test_file = "tests/wf/wc-tool.cwl"
-        job_file = "tests/wf/wc-job.json"
+        test_file = "tests/echo.cwl"
         error_code, stdout, stderr = get_main_output(
             [
                 "--debug",
                 "--default-container",
-                "debian",
+                "debian:stable-slim",
                 "--user-space-docker-cmd=" + udocker,
                 get_data(test_file),
-                get_data(job_file),
+                "--inp",
+                "hello",
             ]
         )
 
@@ -79,7 +79,7 @@ def test_udocker_should_display_memory_usage(udocker: str, tmp_path: Path) -> No
         error_code, stdout, stderr = get_main_output(
             [
                 "--enable-ext",
-                "--default-container=debian",
+                "--default-container=debian:stable-slim",
                 "--user-space-docker-cmd=" + udocker,
                 get_data("tests/wf/timelimit.cwl"),
                 "--sleep_time",
